{{/*
    Expand the name of the chart, and normalize as a legal kubernetes resource name
*/}}
{{- define "app-utils.name" -}}
{{- default .Chart.Name .Values.nameOverride | trunc 63 | trimSuffix "-" -}}
{{- end -}}

{{/*
    Create a default fully qualified app name.
    We truncate at 63 chars because some Kubernetes name fields are limited to this (by the DNS naming spec).
    If release name contains chart name it will be used as a full name.
*/}}
{{- define "app-utils.fullname" -}}
{{-  if .Values.fullnameOverride -}}
{{- .Values.fullnameOverride | trunc 63 | trimSuffix "-" -}}
{{- else -}}
{{- $name := default .Chart.Name .Values.nameOverride -}}
{{- if contains $name .Release.Name -}}
{{- .Release.Name | trunc 63 | trimSuffix "-" -}}
{{- else -}}
{{- printf "%s-%s" .Release.Name $name | trunc 63 | trimSuffix "-" -}}
{{- end -}}
{{- end -}}
{{- end -}}

{{/*
    Create chart name and version as used by the chart label.
*/}}
{{- define "app-utils.chart" -}}
{{- printf "%s-%s" .Chart.Name .Chart.Version | replace "+" "_" | trunc 63 | trimSuffix "-" -}}
{{- end -}}

{{/*
    Common tags to be added as labels
*/}}
{{- define "app-utils.tags" -}}
sguid: {{ include "app-utils.sguid" . }}
owner: {{ include "app-utils.owner" . }}
stage: {{ include "app-utils.stage" . }}
sku: {{ include "app-utils.sku" . }}
{{- end -}}

{{/*
    SBU Common Annotations
    All Kubernetes resources must include SBU required annotations: https://confluence.carbonblack.local/display/cbengx/SBU+AWS+Tagging+Policy
*/}}
{{- define "app-utils.annotations" -}}
sbu.vmware.com/owner: {{ required "You must specify the 'owner'" .Values.standardTags.owner }}
sbu.vmware.com/sguid: {{ required "You must specify the 'sguid'" .Values.sguid }}
{{ if .Values.standardTags.src_url -}}
sbu.vmware.com/src_url: {{ .Values.standardTags.src_url }}
{{- else -}}
sbu.vmware.com/src_url: {{ .Values.src_url | default "https://gitlab.bit9.local/mcs2/infrastructure-charts" }}
{{- end }}
sbu.vmware.com/stage: {{ .Values.global.envCategory | default "dev" }}
sbu.vmware.com/sku: {{ required "You must specify the 'sku'" .Values.standardTags.sku }}
{{- end -}}

{{/*
    Common labels
*/}}
{{- define "app-utils.labels" -}}
{{ include "app-utils.selectorLabels" . }}
helm.sh/chart: {{ include "app-utils.chart" . }}
{{- if .Chart.Version }}
app.kubernetes.io/version: {{ .Chart.Version | quote }}
{{- end }}
app.kubernetes.io/managed-by: {{ .Release.Service }}
app.kubernetes.io/instance: {{ include "app-utils.chart" . }}
app.kubernetes.io/component: {{ .Values.component | default "application" }}
app.kubernetes.io/part-of: {{ .Values.partOf | default "cbc"}}
{{- if .Values.wavefront }}
stack: {{ .Values.wavefront.stackId }}
{{- end }}
{{- end -}}

{{/*
    Selector labels
*/}}
{{- define "app-utils.selectorLabels" -}}
app.kubernetes.io/name: {{ .Chart.Name }}
app.kubernetes.io/release: {{ .Release.Name }}
{{- end -}}

{{/*
    Normalize owner's email
*/}}
{{- define "app-utils.owner" -}}
{{ required "You must specify the 'standardTags.owner'" .Values.standardTags.owner | replace "@" "-" }}
{{- end -}}

{{/*
    Normailze sguid
*/}}
{{- define "app-utils.sguid" -}}
{{ required "You must specify the 'sguid'" .Values.sguid | replace ":" "-" }}
{{- end -}}

{{/*
    Normalize sku
*/}}
{{- define "app-utils.sku" -}}
{{ required "You must specify the 'standardTags.sku'" .Values.standardTags.sku | replace ":" "-" }}
{{- end -}}

{{/*
    Check stage
*/}}
{{- define "app-utils.stage" -}}
{{ required "You must specify the 'standardTags.stage'" .Values.standardTags.stage }}
{{- end -}}

{{/*
    TODO 4 FIPS enpoints below can probably be consolidated into a single pipeline
    Check for s3 FIPS endpoint override
*/}}
{{- define "app-utils.awsEndpointOverride.s3" -}}
{{- if .Values.global.awsEndpointOverride -}}
{{ .Values.global.awsEndpointOverride.s3 }}
{{- end -}}
{{- end -}}

{{/*
    Check for lambda FIPS endpoint override
*/}}
{{- define "app-utils.awsEndpointOverride.lambda" -}}
{{- if .Values.global.awsEndpointOverride -}}
{{ .Values.global.awsEndpointOverride.lambda }}
{{- end -}}
{{- end -}}

{{/*
    Check for elasticsearch FIPS endpoint override
*/}}
{{- define "app-utils.awsEndpointOverride.elasticsearch" -}}
{{- if .Values.global.awsEndpointOverride -}}
{{ .Values.global.awsEndpointOverride.elasticsearch }}
{{- end -}}
{{- end -}}

{{/*
    Check for kinesisfirehose FIPS endpoint override
*/}}
{{- define "app-utils.awsEndpointOverride.kinesisfirehose" -}}
{{- if .Values.global.awsEndpointOverride -}}
{{ .Values.global.awsEndpointOverride.kinesisfirehose }}
{{- end -}}
{{- end -}}

{{/*
    set docker image tags. Example usage:
    image: {{ .Values.global.registryPrefix}}/platform-access/xxx:{{ include "app-utils.imageTag" . }}
*/}}
{{- define "app-utils.imageTag" -}}
{{ "" | regexReplaceAll "^\\d+.\\d+.\\d+-" .Chart.Version }}
{{- end -}}